/*
 * Created on Oct 18, 2010
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 * 
 * Copyright @2010-2011 the original author or authors.
 */
package org.fest.assertions.error;

import static org.joda.time.Seconds.secondsBetween;

import org.joda.time.DateTime;

/**
 * Creates an error message indicating that an assertion that verifies that a {@link DateTime} is in same year, month, day of month,
 * hour, minute and second as another one failed.
 * 
 * @author Joel Costigliola
 */
public class ShouldBeInSameSecond extends BasicErrorMessageFactory {

  /**
   * Creates a new </code>{@link ShouldBeInSameSecond}</code>.
   * @param actual the actual value in the failed assertion.
   * @param other the value used in the failed assertion to compare the actual value to.
   * @return the created {@code ErrorMessageFactory}.
   */
  public static ErrorMessageFactory shouldBeInSameSecond(DateTime actual, DateTime other) {
    return new ShouldBeInSameSecond(actual, other);
  }

  private ShouldBeInSameSecond(DateTime actual, DateTime other) {
    super("Expecting:\n<%s>\n to be on same year, month, day, hour, minute and second as\n<%s>\n but they differ of <%s> seconds", actual, other, secondsBetween(actual,other).getSeconds());
  }
}
